@@ -30,6 +30,11 @@ void atksharp_object_override_ref_state_set (GType gtype, gpointer cb);
 
 AtkStateSet* atksharp_object_base_ref_state_set (AtkObject *base);
 
+void atksharp_object_override_get_index_in_parent (GType gtype, gpointer cb);
+
+void atksharp_object_override_ref_relation_set (GType gtype, gpointer cb);
+
+AtkRelationSet* atksharp_object_base_ref_relation_set (AtkObject *base);
 
 void
 atksharp_object_override_get_n_children (GType gtype, gpointer cb)
@@ -67,3 +72,32 @@ atksharp_object_base_ref_state_set (AtkObject *atk_obj)
 		return (*parent->ref_state_set) (atk_obj);
 	return NULL;
 }
+
+void
+atksharp_object_override_get_index_in_parent (GType gtype, gpointer cb)
+{
+	AtkObjectClass *klass = g_type_class_peek (gtype);
+	if (!klass)
+		klass = g_type_class_ref (gtype);
+	((AtkObjectClass *) klass)->get_index_in_parent = cb;
+}
+
+void
+atksharp_object_override_ref_relation_set (GType gtype, gpointer cb)
+{
+	AtkObjectClass *klass = g_type_class_peek (gtype);
+	if (!klass)
+		klass = g_type_class_ref (gtype);
+	((AtkObjectClass *) klass)->ref_relation_set = cb;
+}
+
+AtkRelationSet*
+atksharp_object_base_ref_relation_set (AtkObject *atk_obj)
+{
+	AtkObjectClass *parent = g_type_class_peek (ATK_TYPE_OBJECT);
+	
+	if (parent->ref_relation_set)
+		return (*parent->ref_relation_set) (atk_obj);
+	return NULL;
+}
+
